@@ -30,14 +30,14 @@ tu <- convert_blanks_to_na(tu)
 # ---- Derivations ----
 
 # Get list of ADSL vars required for derivations - here we assume randomized study
-adsl_vars <- vars(RANDDT)
+adsl_vars <- exprs(RANDDT)
 
 # Join ADSL vars to RS
 adrs <- rs %>%
   derive_vars_merged(
     dataset_add = adsl,
     new_vars = adsl_vars,
-    by_vars = vars(STUDYID, USUBJID)
+    by_vars = exprs(STUDYID, USUBJID)
   )
 
 # ---- Company-specific pre-processing ----
@@ -79,8 +79,8 @@ adrs <- adrs %>%
   restrict_derivation(
     derivation = derive_var_extreme_flag,
     args = params(
-      by_vars = vars(STUDYID, USUBJID, ADT),
-      order = vars(AVAL, RSSEQ),
+      by_vars = exprs(STUDYID, USUBJID, ADT),
+      order = exprs(AVAL, RSSEQ),
       new_var = ANL01FL,
       mode = "last"
     ),
@@ -91,17 +91,21 @@ adrs <- adrs %>%
 
 # Progressive disease
 adrs <- adrs %>%
-  derive_param_extreme_event(
-    dataset_adsl = adsl,
-    dataset_source = adrs,
-    filter_source = PARAMCD == "OVR" & AVALC == "PD" & ANL01FL == "Y",
-    order = vars(ADT, RSSEQ),
-    set_values_to = vars(
+  derive_extreme_records(
+    dataset_ref = adsl,
+    dataset_add = adrs,
+    by_vars = exprs(STUDYID, USUBJID),
+    filter_add = PARAMCD == "OVR" & AVALC == "PD" & ANL01FL == "Y",
+    order = exprs(ADT, RSSEQ),
+    mode = "first",
+    exist_flag = AVALC,
+    set_values_to = exprs(
       PARAMCD = "PD",
       PARAM = "Disease Progression by Investigator",
       PARCAT1 = "Tumor Response",
       PARCAT2 = "Investigator",
       PARCAT3 = "Recist 1.1",
+      AVAL = yn_to_numeric(AVALC),
       ANL01FL = "Y"
     )
   )
@@ -120,12 +124,13 @@ adrs <- adrs %>%
     filter_source = PARAMCD == "OVR" & AVALC %in% c("CR", "PR") & ANL01FL == "Y",
     source_pd = pd,
     source_datasets = list(adrs = adrs),
-    set_values_to = vars(
+    set_values_to = exprs(
       PARAMCD = "RSP",
       PARAM = "Response by Investigator (confirmation not required)",
       PARCAT1 = "Tumor Response",
       PARCAT2 = "Investigator",
       PARCAT3 = "Recist 1.1",
+      AVAL = yn_to_numeric(AVALC),
       ANL01FL = "Y"
     )
   )
@@ -147,12 +152,13 @@ adrs <- adrs %>%
     source_datasets = list(adrs = adrs),
     reference_date = RANDDT,
     ref_start_window = 42,
-    set_values_to = vars(
+    set_values_to = exprs(
       PARAMCD = "CB",
       PARAM = "Clinical Benefit by Investigator (confirmation for response not required)",
       PARCAT1 = "Tumor Response",
       PARCAT2 = "Investigator",
       PARCAT3 = "Recist 1.1",
+      AVAL = yn_to_numeric(AVALC),
       ANL01FL = "Y"
     )
   )
@@ -166,29 +172,34 @@ adrs <- adrs %>%
     source_datasets = list(adrs = adrs),
     reference_date = RANDDT,
     ref_start_window = 42,
-    set_values_to = vars(
+    set_values_to = exprs(
       PARAMCD = "BOR",
       PARAM = "Best Overall Response by Investigator (confirmation not required)",
       PARCAT1 = "Tumor Response",
       PARCAT2 = "Investigator",
       PARCAT3 = "Recist 1.1",
+      AVAL = aval_resp(AVALC),
       ANL01FL = "Y"
     )
   )
 
 # Best overall response of CR/PR
 adrs <- adrs %>%
-  derive_param_extreme_event(
-    dataset_adsl = adsl,
-    dataset_source = adrs,
-    filter_source = PARAMCD == "BOR" & AVALC %in% c("CR", "PR") & ANL01FL == "Y",
-    order = vars(ADT, RSSEQ),
-    set_values_to = vars(
+  derive_extreme_records(
+    dataset_ref = adsl,
+    dataset_add = adrs,
+    by_vars = exprs(STUDYID, USUBJID),
+    filter_add = PARAMCD == "BOR" & AVALC %in% c("CR", "PR") & ANL01FL == "Y",
+    order = exprs(ADT, RSSEQ),
+    mode = "first",
+    exist_flag = AVALC,
+    set_values_to = exprs(
       PARAMCD = "BCP",
       PARAM = "Best Overall Response of CR/PR by Investigator (confirmation not required)",
       PARCAT1 = "Tumor Response",
       PARCAT2 = "Investigator",
       PARCAT3 = "Recist 1.1",
+      AVAL = yn_to_numeric(AVALC),
       ANL01FL = "Y"
     )
   )
@@ -201,12 +212,13 @@ adrs <- adrs %>%
     source_pd = pd,
     source_datasets = list(adrs = adrs),
     ref_confirm = 28,
-    set_values_to = vars(
+    set_values_to = exprs(
       PARAMCD = "CRSP",
       PARAM = "Confirmed Response by Investigator",
       PARCAT1 = "Tumor Response",
       PARCAT2 = "Investigator",
       PARCAT3 = "Recist 1.1",
+      AVAL = yn_to_numeric(AVALC),
       ANL01FL = "Y"
     )
   )
@@ -226,12 +238,13 @@ adrs <- adrs %>%
     source_datasets = list(adrs = adrs),
     reference_date = RANDDT,
     ref_start_window = 42,
-    set_values_to = vars(
+    set_values_to = exprs(
       PARAMCD = "CCB",
       PARAM = "Confirmed Clinical Benefit by Investigator",
       PARCAT1 = "Tumor Response",
       PARCAT2 = "Investigator",
       PARCAT3 = "Recist 1.1",
+      AVAL = yn_to_numeric(AVALC),
       ANL01FL = "Y"
     )
   ) %>%
@@ -243,26 +256,31 @@ adrs <- adrs %>%
     reference_date = RANDDT,
     ref_start_window = 42,
     ref_confirm = 28,
-    set_values_to = vars(
+    set_values_to = exprs(
       PARAMCD = "CBOR",
       PARAM = "Best Confirmed Overall Response by Investigator",
       PARCAT1 = "Tumor Response",
       PARCAT2 = "Investigator",
       PARCAT3 = "Recist 1.1",
+      AVAL = aval_resp(AVALC),
       ANL01FL = "Y"
     )
   ) %>%
-  derive_param_extreme_event(
-    dataset_adsl = adsl,
-    dataset_source = adrs,
-    filter_source = PARAMCD == "CBOR" & AVALC %in% c("CR", "PR") & ANL01FL == "Y",
-    order = vars(ADT, RSSEQ),
-    set_values_to = vars(
+  derive_extreme_records(
+    dataset_ref = adsl,
+    dataset_add = adrs,
+    by_vars = exprs(STUDYID, USUBJID),
+    filter_add = PARAMCD == "CBOR" & AVALC %in% c("CR", "PR") & ANL01FL == "Y",
+    order = exprs(ADT, RSSEQ),
+    mode = "first",
+    exist_flag = AVALC,
+    set_values_to = exprs(
       PARAMCD = "CBCP",
       PARAM = "Best Confirmed Overall Response of CR/PR by Investigator",
       PARCAT1 = "Tumor Response",
       PARCAT2 = "Investigator",
       PARCAT3 = "Recist 1.1",
+      AVAL = yn_to_numeric(AVALC),
       ANL01FL = "Y"
     )
   )
@@ -272,15 +290,18 @@ adsldth <- adsl %>%
   select(STUDYID, USUBJID, DTHDT, !!!adsl_vars)
 
 adrs <- adrs %>%
-  derive_param_extreme_event(
-    dataset_adsl = adsldth,
-    dataset_source = adsldth,
-    filter_source = !is.na(DTHDT),
-    set_values_to = vars(
+  derive_extreme_records(
+    dataset_ref = adsldth,
+    dataset_add = adsldth,
+    by_vars = exprs(STUDYID, USUBJID),
+    filter_add = !is.na(DTHDT),
+    exist_flag = AVALC,
+    set_values_to = exprs(
       PARAMCD = "DEATH",
       PARAM = "Death",
       PARCAT1 = "Reference Event",
       ANL01FL = "Y",
+      AVAL = yn_to_numeric(AVALC),
       ADT = DTHDT
     )
   ) %>%
@@ -288,15 +309,14 @@ adrs <- adrs %>%
 
 # Last disease assessment
 adrs <- adrs %>%
-  derive_param_extreme_event(
-    dataset_adsl = adsl,
-    dataset_source = adrs,
-    filter_source = PARAMCD == "OVR" & ANL01FL == "Y",
-    order = vars(ADT, RSSEQ),
+  derive_extreme_records(
+    dataset_ref = adsl,
+    dataset_add = adrs,
+    by_vars = exprs(STUDYID, USUBJID),
+    filter_add = PARAMCD == "OVR" & ANL01FL == "Y",
+    order = exprs(ADT, RSSEQ),
     mode = "last",
-    # Use this approach to ensure AVALC is not overwritten with a Y
-    new_var = dummy,
-    set_values_to = vars(
+    set_values_to = exprs(
       PARAMCD = "LSTA",
       PARAM = "Last Disease Assessment by Investigator",
       PARCAT1 = "Tumor Response",
@@ -304,8 +324,7 @@ adrs <- adrs %>%
       PARCAT3 = "Recist 1.1",
       ANL01FL = "Y"
     )
-  ) %>%
-  select(-dummy)
+  )
 
 # Measurable disease at baseline
 adslmdis <- adsl %>%
@@ -313,35 +332,26 @@ adslmdis <- adsl %>%
 
 adrs <- adrs %>%
   derive_param_exist_flag(
-    dataset_adsl = adslmdis,
+    dataset_ref = adslmdis,
     dataset_add = tu,
     condition = TUEVAL == "INVESTIGATOR" & TUSTRESC == "TARGET" & VISIT == "BASELINE",
     false_value = "N",
     missing_value = "N",
-    set_values_to = vars(
+    set_values_to = exprs(
       PARAMCD = "MDIS",
       PARAM = "Measurable Disease at Baseline by Investigator",
       PARCAT2 = "Investigator",
       PARCAT3 = "Recist 1.1",
+      AVAL = yn_to_numeric(AVALC),
       ANL01FL = "Y"
     )
   )
 
-# Derive numeric analysis value for cases where AVALC has been derived for new parameters
-adrs <- adrs %>%
-  mutate(
-    AVAL = case_when(
-      AVALC == "Y" ~ 1,
-      AVALC == "N" ~ 0,
-      TRUE ~ AVAL
-    )
-  )
-
 # Derive analysis sequence
 adrs <- adrs %>%
   derive_var_obs_number(
-    by_vars = vars(STUDYID, USUBJID),
-    order = vars(PARAMCD, ADT, VISITNUM, RSSEQ),
+    by_vars = exprs(STUDYID, USUBJID),
+    order = exprs(PARAMCD, ADT, VISITNUM, RSSEQ),
     check_type = "error"
   )
 
@@ -349,7 +359,7 @@ adrs <- adrs %>%
 adrs <- adrs %>%
   derive_vars_merged(
     dataset_add = select(adsl, !!!negate_vars(adsl_vars)),
-    by_vars = vars(STUDYID, USUBJID)
+    by_vars = exprs(STUDYID, USUBJID)
   )
 
 # ---- Save output ----
